"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// Components:
const React = require("react");
const classnames_1 = require("classnames");
const getClassNames_1 = require("../../utils/getClassNames");
exports.Button = React.memo(props => {
    const { btnProps, children, className, disabled, inline, loading, onClick, outLine, style, type } = props;
    // Hook:
    const btnRef = React.useRef(null);
    // Styles:
    const display = inline ? 'inline-block' : 'block';
    let border = 'border-0';
    let background = 'bg-transparent';
    let text = 'text-text';
    switch (true) {
        case outLine:
            background = `bg-transparent hover:bg-${type}`;
            text = `text-${type} hover:text-white`;
            border = `border-2 border-${type}`;
            break;
        case inline:
            background = 'bg-transparent';
            text = `text-${type} hover:underline`;
            break;
        default:
            background = `bg-${type} hover:bg-${type}-dark`;
            text = 'text-white';
    }
    if (disabled) {
        text = 'text-white';
        background = 'bg-grey cursor-not-allowed';
        border = 'border-0';
    }
    const styleOptions = [background, border, display, text];
    const createRipple = (e) => {
        const btn = btnRef.current;
        if (btn) {
            if (btn.getElementsByClassName('Button-ripple').length > 0) {
                btn.getElementsByClassName('Button-ripple')[0].remove();
            }
            const circle = document.createElement('div');
            btn.appendChild(circle);
            const rect = btn.getBoundingClientRect();
            const d = Math.max(btn.clientHeight, btn.clientWidth);
            circle.style.width = circle.style.height = d + 'px';
            circle.style.left = e.clientX - rect.left - d / 2 + 'px';
            circle.style.top = e.clientY - rect.top - d / 2 + 'px';
            circle.classList.add('Button-ripple');
        }
    };
    const handleClick = (e) => {
        if (onClick && !disabled && !loading) {
            createRipple(e);
            onClick();
        }
    };
    return (React.createElement("button", Object.assign({ className: classnames_1.default('Button focus:outline-none transition overflow-hidden relative', getClassNames_1.getClassNames(props), loading && 'spinner', styleOptions, className && className), onClick: handleClick, ref: btnRef, style: style && style }, btnProps), !loading && children));
});
exports.Button.defaultProps = {
    p: '2',
    type: 'first'
};
